@@ -16,5 +16,7 @@ stopifnot(all.equal(intISOana, intISOnum, check.attributes=FALSE))
 intrfr.const <- function (R) R^2/2
 (area.ISO <- polyCub.iso(letterR, intrfr=intrfr.const, center=c(0,0)))
 
-stopifnot(all.equal(spatstat::area.owin(letterR), area.ISO, check.attributes=FALSE))
-## the hole region is subtracted correctly
+stopifnot(all.equal(spatstat::area.owin(letterR),
+                    area.ISO,
+                    check.attributes=FALSE))
+## the hole is subtracted correctly
